@@ -1,5 +1,8 @@
 import requests
 import pyjokes
+import wikipedia
+
+import errors
 
 URL = "http://api.brainshop.ai/get"
 
@@ -9,7 +12,8 @@ apikey = ""
 uiid = ""
 msg = ""
 
-def chatbotsetup(brainid, apikeyuser, uiiduser = "PythonChatbot"):
+
+def chatbotsetup(brainid = 0, apikeyuser = 0, uiiduser = "PythonChatbot"):
     global brain
     global apikey
     global uiid
@@ -44,6 +48,8 @@ def sendmsg(message1):
         'uid': uiid,
         'msg': msg
     }
+    if PARAMS['bid'] == 0 or PARAMS['key'] == 0 or PARAMS['uid'] == "":
+        raise errors.BaseError("ChatBot not setup properly!")
     data = requests.get(url=URL, params=PARAMS).json()['cnt']
     
     return data
